pub fn with_devtools(
rdom: SafeDOM,
root: fn() -> Element,
mutations_notifier: Arc<Notify>,
hovered_node: HoveredNode,
) -> VirtualDomExpand description
Run the VirtualDom with a sidepanel where the devtools are located.
pub fn with_devtools(
rdom: SafeDOM,
root: fn() -> Element,
mutations_notifier: Arc<Notify>,
hovered_node: HoveredNode,
) -> VirtualDomRun the VirtualDom with a sidepanel where the devtools are located.